weblogolib._cgi

Package weblogolib :: Module _cgi |

# Module _cgi

source code

Classes
| Field A representation of an HTML form field.

Functions
resource_string(resource, basefilename) | source code
string_or_none(value) | source code
truth(value) | source code
int_or_none(value) | source code
float_or_none(value) | source code
main(htdocs_directory=None) | source code
send_form(controls, errors=[], htdocs_directory=None) | source code

Variables
| mime_type = `{'eps': 'application/postscript', 'pdf': 'applicat`...``
| extension = `{'eps': 'eps', 'pdf': 'pdf', 'png': 'png', 'svg': `...``
| alphabets = `{'alphabet_auto': None, 'alphabet_protein': weblog`...``
| color_schemes = `{}`
| composition = `{'comp_none': 'none', 'comp_auto': 'auto', 'comp`...``

Variables Details

  ### mime_type Value:
      {'eps': 'application/postscript', 'pdf': 'application/pdf', 'svg': 'im
      age/svg+xml', 'png': 'image/png', 'png_print': 'image/png', 'logodata'
      : 'text/plain', 'jpeg': 'image/jpeg',}

  ### extension Value:
      {'eps': 'eps', 'pdf': 'pdf', 'png': 'png', 'svg': 'svg', 'png_print':
      'png', 'logodata': 'txt', 'jpeg': 'jpeg'}

  ### alphabets Value:
      {'alphabet_auto': None, 'alphabet_protein': weblogolib.unambiguous_pro
      tein_alphabet, 'alphabet_rna': weblogolib.unambiguous_rna_alphabet, 'a
      lphabet_dna': weblogolib.unambiguous_dna_alphabet}

  ### composition Value:
      {'comp_none': 'none', 'comp_auto': 'auto', 'comp_equiprobable': 'equip
      robable', 'comp_CG': 'percentCG', 'comp_Celegans': 'C. elegans', 'comp
      _Dmelanogaster': 'D. melanogaster', 'comp_Ecoli': 'E. coli', 'comp_Hsa
      piens': 'H. sapiens', 'comp_Mmusculus': 'M. musculus', 'comp_Scerevisi
      ae': 'S. cerevisiae'}